"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const co_1 = require("co");
const Context_1 = require("../ioc/Context");
const LogManager_1 = require("../log/LogManager");
const PreinstantiatedSingletonDefinition_1 = require("../ioc/objectdefinition/PreinstantiatedSingletonDefinition");
const ObjectDefinitionAutowiringInspector_1 = require("../ioc/autoconfig/ObjectDefinitionAutowiringInspector");
const ObjectDefinitionStartStopMethodsInspector_1 = require("../ioc/autoconfig/ObjectDefinitionStartStopMethodsInspector");
const ObjectDefinitionLazyLoadingInspector_1 = require("../ioc/autoconfig/ObjectDefinitionLazyLoadingInspector");
const Metrics_1 = require("../metrics/Metrics");
const MysqlConfigManager_1 = require("../mysql/MysqlConfigManager");
class InceptumApp {
    /**
     * Creates a new Inceptum App
     */
    constructor(logger) {
        this.appName = Context_1.Context.getConfig('app.name', 'TestApp');
        LogManager_1.LogManager.setAppName(this.appName);
        this.context = new Context_1.Context(Context_1.Context.getConfig('app.context.name', 'BaseContext'));
        Metrics_1.MetricsManager.registerSingletons(this.appName, this.context);
        this.context.addObjectDefinitionInspector(new ObjectDefinitionAutowiringInspector_1.ObjectDefinitionAutowiringInspector());
        this.context.addObjectDefinitionInspector(new ObjectDefinitionStartStopMethodsInspector_1.ObjectDefinitionStartStopMethodsInspector());
        this.context.addObjectDefinitionInspector(new ObjectDefinitionLazyLoadingInspector_1.ObjectDefinitionLazyLoadingInspector());
        MysqlConfigManager_1.MysqlConfigManager.registerSingletons(this.context);
        this.context.registerDefinition(new PreinstantiatedSingletonDefinition_1.PreinstantiatedSingletonDefinition(LogManager_1.LogManager));
        this.logger = logger || LogManager_1.LogManager.getLogger();
    }
    start() {
        const self = this;
        process.on('SIGINT', () => {
            co_1.default(self.stop().then(() => process.exit()));
        });
        return this.context.lcStart();
    }
    stop() {
        this.logger.info('Shutting down app');
        return this.context.lcStop();
    }
    getContext() {
        return this.context;
    }
    // tslint:disable-next-line:prefer-function-over-method
    getConfig(key, defaultValue) {
        return Context_1.Context.getConfig(key, defaultValue);
    }
    // tslint:disable-next-line:prefer-function-over-method
    hasConfig(key) {
        return Context_1.Context.hasConfig(key);
    }
}
exports.InceptumApp = InceptumApp;
//# sourceMappingURL=InceptumApp.js.map