import * as mysql from 'mysql';
import { Transaction } from '../transaction/TransactionManager';
export declare class MysqlTransaction {
    transaction: Transaction;
    mysqlClient: MysqlClient;
    /**
     *
     * @param {MysqlClient} myslqClient
     * @param transaction
     */
    constructor(mysqlClient: MysqlClient, transaction: Transaction);
    begin(): any;
    query(sql: string, ...bindArrs: any[]): Promise<any>;
    queryAssoc(sql: string, bindObj: object): Promise<any>;
    end(): void;
}
export interface ConnectionPool {
    getConnection(cb: (err: Error, connection: mysql.IConnection) => void): void;
    end(): void;
}
export interface ConfigurationObject {
    enable57Mode?: boolean;
    master?: mysql.IPoolConfig;
    slave?: mysql.IPoolConfig;
}
/**
 * A MySQL client you can use to execute queries against MySQL
 */
export declare class MysqlClient {
    static startMethod: string;
    static stopMethod: string;
    configuration: ConfigurationObject;
    name: string;
    masterPool: ConnectionPool;
    slavePool: ConnectionPool;
    enable57Mode: boolean;
    connectionPoolCreator: (config: mysql.IPoolConfig) => ConnectionPool;
    constructor();
    initialise(): void;
    /**
     * Runs a function in a transaction. The function must receive one parameter that will be of class
     * {MysqlTransaction} and that you need to use to run all queries in this transaction
     *
     * @param {boolean} readonly Whether the transaction needs to be readonly or not
     * @param {Function} func A function that returns a promise that will execute all the queries wanted in this transaction
     * @returns {Promise} A promise that will execute the whole transaction
     */
    runInTransaction(readonly: boolean, func: (transaction: MysqlTransaction) => Promise<any>): any;
    shutdown(): void;
    getFullPoolConfig(partial: mysql.IPoolConfig): mysql.IPoolConfig;
    getConnectionPoolForReadonly(readonly: boolean): ConnectionPool;
}
export declare const TestUtil: {
    runQueryOnPool: (connection: mysql.IConnection, sql: string, bindsArr: any[]) => Promise<any>;
};
